==> mvBlueCOUGAR-1.10.49.127.tar.gz: mvimpact_acquire-1.10.49.127/apps/mvIPConfigure/IPConfigureFrame.h <==
//-----------------------------------------------------------------------------
#ifndef IPConfigureFrameH
#define IPConfigureFrameH IPConfigureFrameH
//-----------------------------------------------------------------------------
#include "wx/wx.h"
#include <apps/Common/wxAbstraction.h>
#include <map>
#include <string>
#include "TLILibImports.h"

#define LOGGED_TLI_CALL(FN, PARAMS, LOGGER_CALL) \
	{ \
		status = FN PARAMS; \
		if( status != 0 ) \
		{ \
			string functionName(__FUNCTION__); \
			string FNString(#FN); \
			string PARAMSString(#PARAMS); \
			LOGGER_CALL( wxString::Format( wxT("%s: ERROR while calling %s%s: %d.\n"), ConvertedString(functionName).c_str(), ConvertedString(FNString).c_str(), ConvertedString(PARAMSString).c_str(), status ), wxColour(255, 0, 0) ); \
		} \
	}

//-----------------------------------------------------------------------------
struct InterfaceInfo
//-----------------------------------------------------------------------------
{
	explicit InterfaceInfo() : currentIPAddress_(), currentSubnetMask_(), currentDefaultGateway_(), persistentIPAddress_(),
		persistentSubnetMask_(), persistentDefaultGateway_(), MACAddress_(), supportsLLA_(0), supportsDHCP_(0), supportsPersistentIP_(0),
		LLAEnabled_(1), DHCPEnabled_(0), persistentIPEnabled_(0) {}
	std::string currentIPAddress_;
	std::string currentSubnetMask_;
	std::string currentDefaultGateway_;
	std::string persistentIPAddress_;
	std::string persistentSubnetMask_;
	std::string persistentDefaultGateway_;
	std::string MACAddress_;
	unsigned char supportsLLA_;
	unsigned char supportsDHCP_;
	unsigned char supportsPersistentIP_;
	unsigned char LLAEnabled_;
	unsigned char DHCPEnabled_;
	unsigned char persistentIPEnabled_;
};

//-----------------------------------------------------------------------------
struct DetecedDeviceInfo
//-----------------------------------------------------------------------------
{
	std::string deviceName_;
	std::string deviceSerial_;
	std::string modelName_;
	std::string manufacturer_;
	std::string userDefinedName_;
	unsigned char supportsUserDefinedName_;
	std::string adapterIPAddress_;
	unsigned int interfaceCount_;
	static const size_t MAX_INTERFACE_COUNT = 4;
	InterfaceInfo interfaceInfo_[MAX_INTERFACE_COUNT];
	DetecedDeviceInfo( const std::string& deviceName, const std::string& devSerial, const std::string& modelName,
		const std::string& manufacturer, const std::string& userDefinedName, unsigned char const supportsUserDefinedName, 
		std::string adapterIPAddress, unsigned int interfaceCount )
		: deviceName_(deviceName), deviceSerial_(devSerial), modelName_(modelName), manufacturer_(manufacturer), userDefinedName_(userDefinedName),
		supportsUserDefinedName_(supportsUserDefinedName), adapterIPAddress_(adapterIPAddress), interfaceCount_(interfaceCount) {}
};

class DeviceListCtrl;
class wxSplitterWindow;
class wxSpinCtrl;

//-----------------------------------------------------------------------------
class IPStringValidator : public wxTextValidator
//-----------------------------------------------------------------------------
{
public:
	IPStringValidator( wxString* valPtr = NULL );
};

//-----------------------------------------------------------------------------
class IPConfigureFrame : public wxFrame
//-----------------------------------------------------------------------------
{
public:
		IPConfigureFrame(const wxString& title, const wxPoint& pos, const wxSize& size);
	   ~IPConfigureFrame();
	int ConfigureDevice( int deviceIndex );
	void OnListItemSelected( int deviceIndex );
	void OnListItemDeselected( int deviceIndex );
	void WriteLogMessage( const wxString& msg, const wxTextAttr& style = wxTextAttr(wxColour(0, 0, 0)) );
protected:
	// event handlers (these functions should _not_ be virtual)
	void OnAbout( wxCommandEvent& e );
	void OnAssignTemporaryIP( wxCommandEvent& e );
	void OnBtnApplyChanges( wxCommandEvent& e );
	void OnBtnConfigure( wxCommandEvent& e );
	void OnCBUseDHCP( wxCommandEvent& e );
	void OnCBUsePersistentIP( wxCommandEvent& e );
	void OnInterfaceSelectorTextChanged( wxCommandEvent& e );
	void OnPersistentIPTextChanged( wxCommandEvent& e );
	void OnPersistentNetmaskTextChanged( wxCommandEvent& e );
	void OnPersistentGatewayTextChanged( wxCommandEvent& e );
	void OnQuit( wxCommandEvent& e );
	void OnUpdateDeviceList( wxCommandEvent& e );
private:
	typedef std::map<std::string, DetecedDeviceInfo*> DeviceMap;
	void								BuildList( void );
	std::string							GetDeviceInterfaceStringInfo( MVTLI_INTERFACE_HANDLE hInterface, const std::string& deviceName, unsigned int interfaceIndex, DEVICE_INFO_CMD info );
	std::string							GetDeviceStringInfo( MVTLI_INTERFACE_HANDLE hInterface, const std::string& deviceName, DEVICE_INFO_CMD info );
	void								UpdateDeviceList( void );
	void								UpdateDlgControls( bool boEdit );
	DeviceListCtrl*						m_pDevListCtrl;
	wxButton*							m_pBtnConfigure;
	wxButton*							m_pBtnApplyChanges;
	wxCheckBox*							m_pCBUsePersistentIP;
	wxCheckBox*							m_pCBUseDHCP;
	wxCheckBox*							m_pCBUseLLA;
	wxMenuItem*							m_pMIActionAssignTemporaryIP;
	wxMenuItem*							m_pMIActionUpdateDeviceList;
	wxTextCtrl*							m_pLogWindow;
	wxSpinCtrl*							m_pSCInterfaceSelector;
	wxStaticText*						m_pSTManufacturer;
	wxStaticText*						m_pSTSerialNumber;
	wxStaticText*						m_pSTInterfaceCount;
	wxStaticText*						m_pSTMACAddress;
	wxTextCtrl*							m_pTCUserDefinedName;
	wxStaticText*						m_pSTCurrentIPAddress;
	wxStaticText*						m_pSTCurrentSubnetMask;
	wxStaticText*						m_pSTCurrentDefaultGateway;
	wxStaticText*						m_pSTConnectedToIPAddress;
	wxTextCtrl*							m_pTCPersistentIPAddress;
	wxTextCtrl*							m_pTCPersistentSubnetMask;
	wxTextCtrl*							m_pTCPersistentDefaultGateway;
	wxSplitterWindow*					m_pHorizontalSplitter;
	wxSplitterWindow*					m_pVerticalSplitter;
	static const wxTextAttr				m_ERROR_STYLE;
	MVTLI_HANDLE						m_hTLI;
	IPStringValidator					m_IPStringValidator;
	typedef std::map<std::string, MVTLI_INTERFACE_HANDLE> InterfaceContainer;
	InterfaceContainer					m_TLIInterfaces;
	DeviceMap							m_devices;
	InterfaceInfo						m_interfaceInfo[DetecedDeviceInfo::MAX_INTERFACE_COUNT];

	// any class wishing to process wxWidgets events must use this macro
	DECLARE_EVENT_TABLE()
	//-----------------------------------------------------------------------------
	// IDs for the controls and the menu commands
	enum TMenuItem
	//-----------------------------------------------------------------------------
	{
		miQuit = 1,
		miAbout,
		miAction_AssignTemporaryIP,
		miAction_UpdateDeviceList
	};
	//-----------------------------------------------------------------------------
	enum TWidgetIDs
	//-----------------------------------------------------------------------------
	{
		widVerSplitter = 1,
		widHorSplitter,
		widDeviceManufacturer,
		widDeviceSerial,
		widDeviceInterfaceCount,
		widUserDefinedName,
		widInterfaceSelector,
		widCurrentIPAddress,
		widCurrentSubnetMask,
		widCurrentDefaultGateway,
		widInterfaceMACAddress,
		widConnectToIPAddress,
		widPersistentIPAddress,
		widPersistentSubnetMask,
		widPersistentDefaultGateway,
		widCBUsePersistentIP,
		widCBUseDHCP,
		widBtnConfigure,
		widBtnApplyChanges
	};
};

#endif // IPConfigureFrameH

==> mvBlueCOUGAR-1.10.77.155.tar.gz: mvimpact_acquire-1.10.77.155/apps/mvIPConfigure/IPConfigureFrame.h <==
//-----------------------------------------------------------------------------
#ifndef IPConfigureFrameH
#define IPConfigureFrameH IPConfigureFrameH
//-----------------------------------------------------------------------------
#include "wx/wx.h"
#include "wx/imaglist.h"
#include <apps/Common/wxAbstraction.h>
#include "CustomValidators.h"
#include <map>
#include <string>
#include "TLILibImports.h"

#define LOGGED_TLI_CALL(FN, PARAMS, LOGGER_CALL) \
	{ \
		status = FN PARAMS; \
		if( status != 0 ) \
		{ \
			string functionName(__FUNCTION__); \
			string FNString(#FN); \
			string PARAMSString(#PARAMS); \
			LOGGER_CALL( wxString::Format( wxT("%s: ERROR while calling %s%s: %d.\n"), ConvertedString(functionName).c_str(), ConvertedString(FNString).c_str(), ConvertedString(PARAMSString).c_str(), status ), wxColour(255, 0, 0) ); \
		} \
	}

//-----------------------------------------------------------------------------
struct InterfaceInfo
//-----------------------------------------------------------------------------
{
	explicit InterfaceInfo() : currentIPAddress_(), currentSubnetMask_(), currentDefaultGateway_(), persistentIPAddress_(),
		persistentSubnetMask_(), persistentDefaultGateway_(), MACAddress_(), supportsLLA_(0), supportsDHCP_(0), supportsPersistentIP_(0),
		LLAEnabled_(1), DHCPEnabled_(0), persistentIPEnabled_(0) {}
	std::string currentIPAddress_;
	std::string currentSubnetMask_;
	std::string currentDefaultGateway_;
	std::string persistentIPAddress_;
	std::string persistentSubnetMask_;
	std::string persistentDefaultGateway_;
	std::string MACAddress_;
	unsigned char supportsLLA_;
	unsigned char supportsDHCP_;
	unsigned char supportsPersistentIP_;
	unsigned char LLAEnabled_;
	unsigned char DHCPEnabled_;
	unsigned char persistentIPEnabled_;
};

//-----------------------------------------------------------------------------
struct DetecedDeviceInfo
//-----------------------------------------------------------------------------
{
	std::string deviceName_;
	std::string deviceSerial_;
	std::string modelName_;
	std::string manufacturer_;
	std::string userDefinedName_;
	unsigned char supportsUserDefinedName_;
	std::string adapterIPAddress_;
	std::string adapterNetmask_;
	unsigned int interfaceCount_;
	static const size_t MAX_INTERFACE_COUNT = 4;
	InterfaceInfo interfaceInfo_[MAX_INTERFACE_COUNT];
	DetecedDeviceInfo( const std::string& deviceName, const std::string& devSerial, const std::string& modelName,
		const std::string& manufacturer, const std::string& userDefinedName, unsigned char const supportsUserDefinedName, 
		std::string adapterIPAddress, const std::string& adapterNetmask, unsigned int interfaceCount )
		: deviceName_(deviceName), deviceSerial_(devSerial), modelName_(modelName), manufacturer_(manufacturer), userDefinedName_(userDefinedName),
		supportsUserDefinedName_(supportsUserDefinedName), adapterIPAddress_(adapterIPAddress), adapterNetmask_(adapterNetmask), interfaceCount_(interfaceCount) {}
};

class DeviceListCtrl;
class wxSplitterWindow;
class wxSpinCtrl;

//-----------------------------------------------------------------------------
class IPConfigureFrame : public wxFrame
//-----------------------------------------------------------------------------
{
public:
		IPConfigureFrame(const wxString& title, const wxPoint& pos, const wxSize& size);
	   ~IPConfigureFrame();
	void AssignTemporaryIP( int listItemIndex );
	void OnListItemSelected( int listItemIndex );
	void OnListItemDeselected( int listItemIndex );
	void WriteLogMessage( const wxString& msg, const wxTextAttr& style = wxTextAttr(wxColour(0, 0, 0)) );
protected:
	// event handlers (these functions should _not_ be virtual)
	void OnAbout( wxCommandEvent& e );
	void OnAssignTemporaryIP( wxCommandEvent& e );
	void OnBtnApplyChanges( wxCommandEvent& e );
	void OnBtnConfigure( wxCommandEvent& e );
	void OnCBUseDHCP( wxCommandEvent& e );
	void OnCBUsePersistentIP( wxCommandEvent& e );
	void OnInterfaceSelectorTextChanged( wxCommandEvent& e );
	void OnPersistentIPTextChanged( wxCommandEvent& e );
	void OnPersistentNetmaskTextChanged( wxCommandEvent& e );
	void OnPersistentGatewayTextChanged( wxCommandEvent& e );
	void OnQuit( wxCommandEvent& e );
	void OnUpdateDeviceList( wxCommandEvent& e );
private:
	typedef std::map<std::string, DetecedDeviceInfo*> DeviceMap;
	void								BuildList( void );
	std::string							GetInterfaceStringInfo( MVTLI_INTERFACE_HANDLE hInterface, INTERFACE_INFO_CMD info );
	std::string							GetDeviceInterfaceStringInfo( MVTLI_INTERFACE_HANDLE hInterface, const std::string& deviceName, unsigned int interfaceIndex, DEVICE_INFO_CMD info );
	std::string							GetDeviceStringInfo( MVTLI_INTERFACE_HANDLE hInterface, const std::string& deviceName, DEVICE_INFO_CMD info );
	void								UpdateDeviceList( void );
	void								UpdateDlgControls( bool boEdit );
	DeviceListCtrl*						m_pDevListCtrl;
	wxButton*							m_pBtnConfigure;
	wxButton*							m_pBtnApplyChanges;
	wxCheckBox*							m_pCBUsePersistentIP;
	wxCheckBox*							m_pCBUseDHCP;
	wxCheckBox*							m_pCBUseLLA;
	wxMenuItem*							m_pMIActionAssignTemporaryIP;
	wxMenuItem*							m_pMIActionUpdateDeviceList;
	wxTextCtrl*							m_pLogWindow;
	wxSpinCtrl*							m_pSCInterfaceSelector;
	wxStaticText*						m_pSTManufacturer;
	wxStaticText*						m_pSTSerialNumber;
	wxStaticText*						m_pSTInterfaceCount;
	wxStaticText*						m_pSTMACAddress;
	wxTextCtrl*							m_pTCUserDefinedName;
	wxStaticText*						m_pSTCurrentIPAddress;
	wxStaticText*						m_pSTCurrentSubnetMask;
	wxStaticText*						m_pSTCurrentDefaultGateway;
	wxStaticText*						m_pSTConnectedToIPAddress;
	wxStaticText*						m_pSTConnectedToNetmask;
	wxTextCtrl*							m_pTCPersistentIPAddress;
	wxTextCtrl*							m_pTCPersistentSubnetMask;
	wxTextCtrl*							m_pTCPersistentDefaultGateway;
	wxSplitterWindow*					m_pHorizontalSplitter;
	wxSplitterWindow*					m_pVerticalSplitter;
	wxImageList							m_iconList;
	static const wxTextAttr				m_ERROR_STYLE;
	MVTLI_HANDLE						m_hTLI;
	IPv4StringValidator					m_IPv4StringValidator;
	typedef std::map<std::string, MVTLI_INTERFACE_HANDLE> InterfaceContainer;
	InterfaceContainer					m_TLIInterfaces;
	DeviceMap							m_devices;
	InterfaceInfo						m_interfaceInfo[DetecedDeviceInfo::MAX_INTERFACE_COUNT];

	// any class wishing to process wxWidgets events must use this macro
	DECLARE_EVENT_TABLE()
	//-----------------------------------------------------------------------------
	// IDs for the controls and the menu commands
	enum TMenuItem
	//-----------------------------------------------------------------------------
	{
		miQuit = 1,
		miAbout,
		miAction_AssignTemporaryIP,
		miAction_UpdateDeviceList
	};
	//-----------------------------------------------------------------------------
	enum TWidgetIDs
	//-----------------------------------------------------------------------------
	{
		widVerSplitter = 1,
		widHorSplitter,
		widDeviceManufacturer,
		widDeviceSerial,
		widDeviceInterfaceCount,
		widUserDefinedName,
		widInterfaceSelector,
		widCurrentIPAddress,
		widCurrentSubnetMask,
		widCurrentDefaultGateway,
		widInterfaceMACAddress,
		widConnectToIPAddress,
		widConnectToNetmask,
		widPersistentIPAddress,
		widPersistentSubnetMask,
		widPersistentDefaultGateway,
		widCBUsePersistentIP,
		widCBUseDHCP,
		widBtnConfigure,
		widBtnApplyChanges
	};
};

#endif // IPConfigureFrameH
